@@ -413,11 +413,13 @@ def extrude_triangulation(vertices,
 
 def triangulate_polygon(polygon,
                         triangle_args=None,
+                        engine=None,
                         **kwargs):
     """
     Given a shapely polygon create a triangulation using a
-    python interface to `triangle.c`:
-    > `pip install triangle`
+    python interface to `triangle.c` or mapbox-earcut.
+    > pip install triangle
+    > pip install mapbox_earcut
 
     Parameters
     ---------
@@ -425,6 +427,8 @@ def triangulate_polygon(polygon,
         Polygon object to be triangulated
     triangle_args : str or None
         Passed to triangle.triangulate i.e: 'p', 'pq30'
+    engine : None or str
+      Any value other than 'earcut' will use `triangle`
 
     Returns
     --------------
@@ -433,6 +437,22 @@ def triangulate_polygon(polygon,
     faces : (n, 3) int
        Index of vertices that make up triangles
     """
+    if engine == 'earcut':
+        from mapbox_earcut import triangulate_float64
+
+        # get vertices as sequence where exterior is the first value
+        vertices = [np.array(polygon.exterior)]
+        vertices.extend(np.array(i) for i in polygon.interiors)
+        # record the index from the length of each vertex array
+        rings = np.cumsum([len(v) for v in vertices])
+        # stack vertices into (n, 2) float array
+        vertices = np.vstack(vertices)
+        # run triangulation
+        faces = triangulate_float64(vertices, rings).reshape(
+            (-1, 3)).astype(np.int64).reshape((-1, 3))
+
+        return vertices, faces
+
     # do the import here for soft requirement
     from triangle import triangulate
     # set default triangulation arguments if not specified
