@@ -6,7 +6,6 @@ Fill holes and fix winding and normals of meshes.
 """
 
 import numpy as np
-import networkx as nx
 
 from . import graph
 from . import triangles
@@ -16,6 +15,15 @@ from .grouping import group_rows
 from .geometry import faces_to_edges
 
 
+try:
+    import networkx as nx
+except BaseException as E:
+    # create a dummy module which will raise the ImportError
+    # or other exception only when someone tries to use networkx
+    from .exceptions import ExceptionModule
+    nx = ExceptionModule(E)
+
+
 def fix_winding(mesh):
     """
     Traverse and change mesh faces in-place to make sure winding
@@ -43,14 +51,14 @@ def fix_winding(mesh):
     # start a traversal for every connected component
     for components in nx.connected_components(graph_all):
         # get a subgraph for this component
-        graph = graph_all.subgraph(components)
+        g = graph_all.subgraph(components)
         # get the first node in the graph in a way that works on nx's
         # new API and their old API
-        start = next(iter(graph.nodes()))
+        start = next(iter(g.nodes()))
 
         # we traverse every pair of faces in the graph
         # we modify mesh.faces and mesh.face_normals in place
-        for face_pair in nx.bfs_edges(graph, start):
+        for face_pair in nx.bfs_edges(g, start):
             # for each pair of faces, we convert them into edges,
             # find the edge that both faces share and then see if edges
             # are reversed in order as you would expect
@@ -134,19 +142,22 @@ def fix_normals(mesh, multibody=False):
     Fix the winding and direction of a mesh face and
     face normals in-place.
 
-    Really only meaningful on watertight meshes, but will orient all
+    Really only meaningful on watertight meshes but will orient all
     faces and winding in a uniform way for non-watertight face
     patches as well.
 
     Parameters
     -------------
-    mesh:      Trimesh object
-    multibody: bool, if True try to correct normals direction
-                     on every body.
+    mesh : trimesh.Trimesh
+      Mesh to fix normals on
+    multibody : bool
+      if True try to correct normals direction
+      on every body rather than just one
 
     Alters
     --------------
-    mesh.faces: will flip columns on inverted faces
+    mesh.faces
+      Will flip columns on inverted faces
     """
     # traverse face adjacency to correct winding
     fix_winding(mesh)
@@ -173,7 +184,7 @@ def broken_faces(mesh, color=None):
     broken = [k for k, v in dict(adjacency.degree()).items()
               if v != 3]
     broken = np.array(broken)
-    if color is not None:
+    if color is not None and broken.size != 0:
         # if someone passed a broken color
         color = np.array(color)
         if not (color.shape == (4,) or color.shape == (3,)):
@@ -184,14 +195,15 @@ def broken_faces(mesh, color=None):
 
 def fill_holes(mesh):
     """
-    Fill single- triangle holes on triangular meshes by adding new triangles
-    to fill the holes. New triangles will have proper winding and normals,
-    and if face colors exist the color of the last face will be assigned
-    to the new triangles.
+    Fill single- triangle holes on triangular meshes by adding
+    new triangles to fill the holes. New triangles will have
+    proper winding and normals, and if face colors exist the color
+    of the last face will be assigned to the new triangles.
 
     Parameters
     ---------
-    mesh: Trimesh object
+    mesh : trimesh.Trimesh
+      Mesh will be repaired in- place
     """
 
     def hole_to_faces(hole):
@@ -226,23 +238,25 @@ def fill_holes(mesh):
     if mesh.is_watertight:
         return True
 
-    # we know that in a watertight mesh, every edge will be included twice
-    # thus, every edge which appears only once is part of the boundary of a
-    # hole.
-    boundary_groups = group_rows(mesh.edges_sorted, require_count=1)
+    # we know that in a watertight mesh every edge will be included twice
+    # thus every edge which appears only once is part of a hole boundary
+    boundary_groups = group_rows(
+        mesh.edges_sorted, require_count=1)
 
+    # mesh is not watertight and we have too few edges
+    # edges to do a repair
+    # since we haven't changed anything return False
     if len(boundary_groups) < 3:
-        watertight = len(boundary_groups) == 0
-        return watertight
+        return False
 
     boundary_edges = mesh.edges[boundary_groups]
     index_as_dict = [{'index': i} for i in boundary_groups]
 
     # we create a graph of the boundary edges, and find cycles.
-    graph = nx.from_edgelist(np.column_stack((boundary_edges,
-                                              index_as_dict)))
-    cycles = np.array(nx.cycle_basis(graph))
-
+    g = nx.from_edgelist(
+        np.column_stack((boundary_edges,
+                         index_as_dict)))
+    cycles = np.array(nx.cycle_basis(g))
     new_faces = []
     new_vertex = []
     for hole in cycles:
@@ -270,9 +284,9 @@ def fill_holes(mesh):
         # we compare the edge from the new face with
         # the boundary edge from the source mesh
         edge_test = face[0:2]
-        edge_boundary = mesh.edges[graph.get_edge_data(*edge_test)['index']]
+        edge_boundary = mesh.edges[g.get_edge_data(*edge_test)['index']]
 
-        # in a well construced mesh, the winding is such that adjacent triangles
+        # in a well construtced mesh, the winding is such that adjacent triangles
         # have reversed edges to each other. Here we check to make sure the
         # edges are reversed, and if they aren't we simply reverse the face
         reversed = edge_test[0] == edge_boundary[1]
@@ -297,6 +311,15 @@ def fill_holes(mesh):
     if not valid.any():
         return False
 
+    # this is usually the case where two vertices of a triangle are just
+    # over tol.merge apart, but the normal calculation is screwed up
+    # these could be fixed by merging the vertices in question here:
+    # if not valid.all():
+    if mesh.visual.defined and mesh.visual.kind == 'face':
+        color = mesh.visual.face_colors
+    else:
+        color = None
+
     # apply the new faces and vertices
     mesh.faces = np.vstack((mesh._data['faces'], new_faces[valid]))
     mesh.vertices = new_vertices
@@ -313,15 +336,14 @@ def fill_holes(mesh):
     # over tol.merge apart, but the normal calculation is screwed up
     # these could be fixed by merging the vertices in question here:
     # if not valid.all():
-    if mesh.visual.defined and mesh.visual.kind == 'face':
+    if color is not None:
         # if face colors exist, assign the last face color to the new faces
         # note that this is a little cheesey, but it is very inexpensive and
         # is the right thing to do if the mesh is a single color.
-        stored = mesh.visual._data['face_colors']
-        color_shape = np.shape(stored)
+        color_shape = np.shape(color)
         if len(color_shape) == 2:
-            new_colors = np.tile(stored[-1], (np.sum(valid), 1))
-            new_colors = np.vstack((stored,
+            new_colors = np.tile(color[-1], (np.sum(valid), 1))
+            new_colors = np.vstack((color,
                                     new_colors))
             mesh.visual.face_colors = new_colors
 
